@@ -7,15 +7,21 @@
  */
 
 // don't load directly
-if ( !defined('ABSPATH') )
-	die('-1');
+if ( ! defined( 'ABSPATH' ) ) {
+	die( '-1' );
+}
+
+/**
+ * @global string $hook_suffix
+ */
+global $hook_suffix;
 ?>
 
 <div class="clear"></div></div><!-- wpbody-content -->
 <div class="clear"></div></div><!-- wpbody -->
 <div class="clear"></div></div><!-- wpcontent -->
 
-<div id="wpfooter">
+<div id="wpfooter" role="contentinfo">
 	<?php
 	/**
 	 * Fires after the opening tag for the admin footer.
@@ -26,9 +32,14 @@ if ( !defined('ABSPATH') )
 	?>
 	<p id="footer-left" class="alignleft">
 		<?php
-		$text = sprintf( __( 'Thank you for creating with <a href="%s">WordPress</a>.' ), __( 'https://wordpress.org/' ) );
+		$text = sprintf(
+			/* translators: %s: https://wordpress.org/ */
+			__( 'Thank you for creating with <a href="%s">WordPress</a>.' ),
+			__( 'https://wordpress.org/' )
+		);
+
 		/**
-		 * Filter the "Thank you" text displayed in the admin footer.
+		 * Filters the "Thank you" text displayed in the admin footer.
 		 *
 		 * @since 2.8.0
 		 *
@@ -40,7 +51,7 @@ if ( !defined('ABSPATH') )
 	<p id="footer-upgrade" class="alignright">
 		<?php
 		/**
-		 * Filter the version/update text displayed in the admin footer.
+		 * Filters the version/update text displayed in the admin footer.
 		 *
 		 * WordPress prints the current version and update information,
 		 * using core_update_footer() at priority 10.
@@ -58,7 +69,7 @@ if ( !defined('ABSPATH') )
 </div>
 <?php
 /**
- * Print scripts or data before the default footer scripts.
+ * Prints scripts or data before the default footer scripts.
  *
  * @since 1.2.0
  *
@@ -66,6 +77,16 @@ if ( !defined('ABSPATH') )
  */
 do_action( 'admin_footer', '' );
 
+/**
+ * Prints scripts and data queued for the footer.
+ *
+ * The dynamic portion of the hook name, `$hook_suffix`,
+ * refers to the global hook suffix of the current page.
+ *
+ * @since 4.6.0
+ */
+do_action( "admin_print_footer_scripts-{$hook_suffix}" ); // phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores
+
 /**
  * Prints any scripts and data queued for the footer.
  *
@@ -74,21 +95,20 @@ do_action( 'admin_footer', '' );
 do_action( 'admin_print_footer_scripts' );
 
 /**
- * Print scripts or data after the default footer scripts.
+ * Prints scripts or data after the default footer scripts.
  *
- * The dynamic portion of the hook name, `$GLOBALS['hook_suffix']`,
+ * The dynamic portion of the hook name, `$hook_suffix`,
  * refers to the global hook suffix of the current page.
  *
  * @since 2.8.0
- *
- * @param string $hook_suffix The current admin page.
  */
-do_action( "admin_footer-" . $GLOBALS['hook_suffix'] );
+do_action( "admin_footer-{$hook_suffix}" ); // phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores
 
 // get_site_option() won't exist when auto upgrading from <= 2.7
-if ( function_exists('get_site_option') ) {
-	if ( false === get_site_option('can_compress_scripts') )
+if ( function_exists( 'get_site_option' ) ) {
+	if ( false === get_site_option( 'can_compress_scripts' ) ) {
 		compression_test();
+	}
 }
 
 ?>
