@@ -25,7 +25,6 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * Constructor.
 	 *
 	 * @since 3.1.0
-	 * @access public
 	 *
 	 * @see WP_List_Table::__construct() for more information on default arguments.
 	 *
@@ -39,32 +38,36 @@ class WP_Terms_List_Table extends WP_List_Table {
 	public function __construct( $args = array() ) {
 		global $post_type, $taxonomy, $action, $tax;
 
-		parent::__construct( array(
-			'plural' => 'tags',
-			'singular' => 'tag',
-			'screen' => isset( $args['screen'] ) ? $args['screen'] : null,
-		) );
+		parent::__construct(
+			array(
+				'plural'   => 'tags',
+				'singular' => 'tag',
+				'screen'   => isset( $args['screen'] ) ? $args['screen'] : null,
+			)
+		);
 
 		$action    = $this->screen->action;
 		$post_type = $this->screen->post_type;
 		$taxonomy  = $this->screen->taxonomy;
 
-		if ( empty( $taxonomy ) )
+		if ( empty( $taxonomy ) ) {
 			$taxonomy = 'post_tag';
+		}
 
-		if ( ! taxonomy_exists( $taxonomy ) )
-			wp_die( __( 'Invalid taxonomy' ) );
+		if ( ! taxonomy_exists( $taxonomy ) ) {
+			wp_die( __( 'Invalid taxonomy.' ) );
+		}
 
 		$tax = get_taxonomy( $taxonomy );
 
 		// @todo Still needed? Maybe just the show_ui part.
-		if ( empty( $post_type ) || !in_array( $post_type, get_post_types( array( 'show_ui' => true ) ) ) )
+		if ( empty( $post_type ) || ! in_array( $post_type, get_post_types( array( 'show_ui' => true ) ) ) ) {
 			$post_type = 'post';
+		}
 
 	}
 
 	/**
-	 *
 	 * @return bool
 	 */
 	public function ajax_user_can() {
@@ -72,14 +75,13 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 * @access public
 	 */
 	public function prepare_items() {
 		$tags_per_page = $this->get_items_per_page( 'edit_' . $this->screen->taxonomy . '_per_page' );
 
 		if ( 'post_tag' === $this->screen->taxonomy ) {
 			/**
-			 * Filter the number of terms displayed per page for the Tags list table.
+			 * Filters the number of terms displayed per page for the Tags list table.
 			 *
 			 * @since 2.8.0
 			 *
@@ -88,7 +90,7 @@ class WP_Terms_List_Table extends WP_List_Table {
 			$tags_per_page = apply_filters( 'edit_tags_per_page', $tags_per_page );
 
 			/**
-			 * Filter the number of terms displayed per page for the Tags list table.
+			 * Filters the number of terms displayed per page for the Tags list table.
 			 *
 			 * @since 2.7.0
 			 * @deprecated 2.8.0 Use edit_tags_per_page instead.
@@ -98,7 +100,7 @@ class WP_Terms_List_Table extends WP_List_Table {
 			$tags_per_page = apply_filters( 'tagsperpage', $tags_per_page );
 		} elseif ( 'category' === $this->screen->taxonomy ) {
 			/**
-			 * Filter the number of terms displayed per page for the Categories list table.
+			 * Filters the number of terms displayed per page for the Categories list table.
 			 *
 			 * @since 2.8.0
 			 *
@@ -107,30 +109,33 @@ class WP_Terms_List_Table extends WP_List_Table {
 			$tags_per_page = apply_filters( 'edit_categories_per_page', $tags_per_page );
 		}
 
-		$search = !empty( $_REQUEST['s'] ) ? trim( wp_unslash( $_REQUEST['s'] ) ) : '';
+		$search = ! empty( $_REQUEST['s'] ) ? trim( wp_unslash( $_REQUEST['s'] ) ) : '';
 
 		$args = array(
 			'search' => $search,
-			'page' => $this->get_pagenum(),
+			'page'   => $this->get_pagenum(),
 			'number' => $tags_per_page,
 		);
 
-		if ( !empty( $_REQUEST['orderby'] ) )
+		if ( ! empty( $_REQUEST['orderby'] ) ) {
 			$args['orderby'] = trim( wp_unslash( $_REQUEST['orderby'] ) );
+		}
 
-		if ( !empty( $_REQUEST['order'] ) )
+		if ( ! empty( $_REQUEST['order'] ) ) {
 			$args['order'] = trim( wp_unslash( $_REQUEST['order'] ) );
+		}
 
 		$this->callback_args = $args;
 
-		$this->set_pagination_args( array(
-			'total_items' => wp_count_terms( $this->screen->taxonomy, compact( 'search' ) ),
-			'per_page' => $tags_per_page,
-		) );
+		$this->set_pagination_args(
+			array(
+				'total_items' => wp_count_terms( $this->screen->taxonomy, compact( 'search' ) ),
+				'per_page'    => $tags_per_page,
+			)
+		);
 	}
 
 	/**
-	 *
 	 * @return bool
 	 */
 	public function has_items() {
@@ -139,36 +144,36 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 * @access public
 	 */
 	public function no_items() {
 		echo get_taxonomy( $this->screen->taxonomy )->labels->not_found;
 	}
 
 	/**
-	 *
 	 * @return array
 	 */
 	protected function get_bulk_actions() {
 		$actions = array();
-		$actions['delete'] = __( 'Delete' );
+
+		if ( current_user_can( get_taxonomy( $this->screen->taxonomy )->cap->delete_terms ) ) {
+			$actions['delete'] = __( 'Delete' );
+		}
 
 		return $actions;
 	}
 
 	/**
-	 *
 	 * @return string
 	 */
 	public function current_action() {
-		if ( isset( $_REQUEST['action'] ) && isset( $_REQUEST['delete_tags'] ) && ( 'delete' === $_REQUEST['action'] || 'delete' === $_REQUEST['action2'] ) )
+		if ( isset( $_REQUEST['action'] ) && isset( $_REQUEST['delete_tags'] ) && ( 'delete' === $_REQUEST['action'] || 'delete' === $_REQUEST['action2'] ) ) {
 			return 'bulk-delete';
+		}
 
 		return parent::current_action();
 	}
 
 	/**
-	 *
 	 * @return array
 	 */
 	public function get_columns() {
@@ -189,7 +194,6 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 *
 	 * @return array
 	 */
 	protected function get_sortable_columns() {
@@ -198,38 +202,44 @@ class WP_Terms_List_Table extends WP_List_Table {
 			'description' => 'description',
 			'slug'        => 'slug',
 			'posts'       => 'count',
-			'links'       => 'count'
+			'links'       => 'count',
 		);
 	}
 
 	/**
-	 * @access public
 	 */
 	public function display_rows_or_placeholder() {
 		$taxonomy = $this->screen->taxonomy;
 
-		$args = wp_parse_args( $this->callback_args, array(
-			'page' => 1,
-			'number' => 20,
-			'search' => '',
-			'hide_empty' => 0
-		) );
+		$args = wp_parse_args(
+			$this->callback_args,
+			array(
+				'taxonomy'   => $taxonomy,
+				'page'       => 1,
+				'number'     => 20,
+				'search'     => '',
+				'hide_empty' => 0,
+			)
+		);
 
 		$page = $args['page'];
 
 		// Set variable because $args['number'] can be subsequently overridden.
 		$number = $args['number'];
 
-		$args['offset'] = $offset = ( $page - 1 ) * $number;
+		$offset         = ( $page - 1 ) * $number;
+		$args['offset'] = $offset;
 
 		// Convert it to table rows.
 		$count = 0;
 
 		if ( is_taxonomy_hierarchical( $taxonomy ) && ! isset( $args['orderby'] ) ) {
 			// We'll need the full set of terms then.
-			$args['number'] = $args['offset'] = 0;
+			$args['number'] = 0;
+			$args['offset'] = $args['number'];
 		}
-		$terms = get_terms( $taxonomy, $args );
+
+		$terms = get_terms( $args );
 
 		if ( empty( $terms ) || ! is_array( $terms ) ) {
 			echo '<tr class="no-items"><td class="colspanchange" colspan="' . $this->get_column_count() . '">';
@@ -269,22 +279,26 @@ class WP_Terms_List_Table extends WP_List_Table {
 
 		foreach ( $terms as $key => $term ) {
 
-			if ( $count >= $end )
+			if ( $count >= $end ) {
 				break;
+			}
 
-			if ( $term->parent != $parent && empty( $_REQUEST['s'] ) )
+			if ( $term->parent != $parent && empty( $_REQUEST['s'] ) ) {
 				continue;
+			}
 
 			// If the page starts in a subtree, print the parents.
 			if ( $count == $start && $term->parent > 0 && empty( $_REQUEST['s'] ) ) {
-				$my_parents = $parent_ids = array();
-				$p = $term->parent;
+				$my_parents = array();
+				$parent_ids = array();
+				$p          = $term->parent;
 				while ( $p ) {
-					$my_parent = get_term( $p, $taxonomy );
+					$my_parent    = get_term( $p, $taxonomy );
 					$my_parents[] = $my_parent;
-					$p = $my_parent->parent;
-					if ( in_array( $p, $parent_ids ) ) // Prevent parent loops.
+					$p            = $my_parent->parent;
+					if ( in_array( $p, $parent_ids ) ) { // Prevent parent loops.
 						break;
+					}
 					$parent_ids[] = $p;
 				}
 				unset( $parent_ids );
@@ -304,45 +318,57 @@ class WP_Terms_List_Table extends WP_List_Table {
 
 			++$count;
 
-			unset( $terms[$key] );
+			unset( $terms[ $key ] );
 
-			if ( isset( $children[$term->term_id] ) && empty( $_REQUEST['s'] ) )
+			if ( isset( $children[ $term->term_id ] ) && empty( $_REQUEST['s'] ) ) {
 				$this->_rows( $taxonomy, $terms, $children, $start, $per_page, $count, $term->term_id, $level + 1 );
+			}
 		}
 	}
 
 	/**
 	 * @global string $taxonomy
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @param int $level
 	 */
 	public function single_row( $tag, $level = 0 ) {
 		global $taxonomy;
- 		$tag = sanitize_term( $tag, $taxonomy );
+		$tag = sanitize_term( $tag, $taxonomy );
 
 		$this->level = $level;
 
-		echo '<tr id="tag-' . $tag->term_id . '">';
+		if ( $tag->parent ) {
+			$count = count( get_ancestors( $tag->term_id, $taxonomy, 'taxonomy' ) );
+			$level = 'level-' . $count;
+		} else {
+			$level = 'level-0';
+		}
+
+		echo '<tr id="tag-' . $tag->term_id . '" class="' . $level . '">';
 		$this->single_row_columns( $tag );
 		echo '</tr>';
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @return string
 	 */
 	public function column_cb( $tag ) {
-		$default_term = get_option( 'default_' . $this->screen->taxonomy );
-
-		if ( current_user_can( get_taxonomy( $this->screen->taxonomy )->cap->delete_terms ) && $tag->term_id != $default_term )
-			return '<label class="screen-reader-text" for="cb-select-' . $tag->term_id . '">' . sprintf( __( 'Select %s' ), $tag->name ) . '</label>'
-				. '<input type="checkbox" name="delete_tags[]" value="' . $tag->term_id . '" id="cb-select-' . $tag->term_id . '" />';
+		if ( current_user_can( 'delete_term', $tag->term_id ) ) {
+			return sprintf(
+				'<label class="screen-reader-text" for="cb-select-%1$s">%2$s</label>' .
+				'<input type="checkbox" name="delete_tags[]" value="%1$s" id="cb-select-%1$s" />',
+				$tag->term_id,
+				/* translators: %s: Taxonomy term name. */
+				sprintf( __( 'Select %s' ), $tag->name )
+			);
+		}
 
 		return '&nbsp;';
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @return string
 	 */
 	public function column_name( $tag ) {
@@ -351,7 +377,7 @@ class WP_Terms_List_Table extends WP_List_Table {
 		$pad = str_repeat( '&#8212; ', max( 0, $this->level ) );
 
 		/**
-		 * Filter display of the term name in the terms list table.
+		 * Filters display of the term name in the terms list table.
 		 *
 		 * The default output may include padding due to the term's
 		 * current level in the term hierarchy.
@@ -361,22 +387,36 @@ class WP_Terms_List_Table extends WP_List_Table {
 		 * @see WP_Terms_List_Table::column_name()
 		 *
 		 * @param string $pad_tag_name The term name, padded if not top-level.
-		 * @param object $tag          Term object.
+		 * @param WP_Term $tag         Term object.
 		 */
 		$name = apply_filters( 'term_name', $pad . ' ' . $tag->name, $tag );
 
 		$qe_data = get_term( $tag->term_id, $taxonomy, OBJECT, 'edit' );
 
-		$uri = ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ? wp_get_referer() : $_SERVER['REQUEST_URI'];
+		$uri = wp_doing_ajax() ? wp_get_referer() : $_SERVER['REQUEST_URI'];
 
-		$edit_link = add_query_arg(
-			'wp_http_referer',
-			urlencode( wp_unslash( $uri ) ),
-			get_edit_term_link( $tag->term_id, $taxonomy, $this->screen->post_type )
+		$edit_link = get_edit_term_link( $tag->term_id, $taxonomy, $this->screen->post_type );
+
+		if ( $edit_link ) {
+			$edit_link = add_query_arg(
+				'wp_http_referer',
+				urlencode( wp_unslash( $uri ) ),
+				$edit_link
+			);
+			$name      = sprintf(
+				'<a class="row-title" href="%s" aria-label="%s">%s</a>',
+				esc_url( $edit_link ),
+				/* translators: %s: Taxonomy term name. */
+				esc_attr( sprintf( __( '&#8220;%s&#8221; (Edit)' ), $tag->name ) ),
+				$name
+			);
+		}
+
+		$out = sprintf(
+			'<strong>%s</strong><br />',
+			$name
 		);
 
-		$out = '<strong><a class="row-title" href="' . esc_url( $edit_link ) . '" title="' . esc_attr( sprintf( __( 'Edit &#8220;%s&#8221;' ), $name ) ) . '">' . $name . '</a></strong><br />';
-
 		$out .= '<div class="hidden" id="inline_' . $qe_data->term_id . '">';
 		$out .= '<div class="name">' . $qe_data->name . '</div>';
 
@@ -391,7 +431,6 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * Gets the name of the default primary column.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @return string Name of the default primary column, in this case, 'name'.
 	 */
@@ -403,11 +442,10 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * Generates and displays row action links.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
-	 * @param object $tag         Tag being acted upon.
-	 * @param string $column_name Current column name.
-	 * @param string $primary     Primary column name.
+	 * @param WP_Term $tag         Tag being acted upon.
+	 * @param string  $column_name Current column name.
+	 * @param string  $primary     Primary column name.
 	 * @return string Row actions output for terms.
 	 */
 	protected function handle_row_actions( $tag, $column_name, $primary ) {
@@ -416,10 +454,8 @@ class WP_Terms_List_Table extends WP_List_Table {
 		}
 
 		$taxonomy = $this->screen->taxonomy;
-		$tax = get_taxonomy( $taxonomy );
-		$default_term = get_option( 'default_' . $taxonomy );
-
-		$uri = ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ? wp_get_referer() : $_SERVER['REQUEST_URI'];
+		$tax      = get_taxonomy( $taxonomy );
+		$uri      = wp_doing_ajax() ? wp_get_referer() : $_SERVER['REQUEST_URI'];
 
 		$edit_link = add_query_arg(
 			'wp_http_referer',
@@ -428,37 +464,62 @@ class WP_Terms_List_Table extends WP_List_Table {
 		);
 
 		$actions = array();
-		if ( current_user_can( $tax->cap->edit_terms ) ) {
-			$actions['edit'] = '<a href="' . esc_url( $edit_link ) . '">' . __( 'Edit' ) . '</a>';
-			$actions['inline hide-if-no-js'] = '<a href="#" class="editinline">' . __( 'Quick&nbsp;Edit' ) . '</a>';
+		if ( current_user_can( 'edit_term', $tag->term_id ) ) {
+			$actions['edit'] = sprintf(
+				'<a href="%s" aria-label="%s">%s</a>',
+				esc_url( $edit_link ),
+				/* translators: %s: Taxonomy term name. */
+				esc_attr( sprintf( __( 'Edit &#8220;%s&#8221;' ), $tag->name ) ),
+				__( 'Edit' )
+			);
+			$actions['inline hide-if-no-js'] = sprintf(
+				'<button type="button" class="button-link editinline" aria-label="%s" aria-expanded="false">%s</button>',
+				/* translators: %s: Taxonomy term name. */
+				esc_attr( sprintf( __( 'Quick edit &#8220;%s&#8221; inline' ), $tag->name ) ),
+				__( 'Quick&nbsp;Edit' )
+			);
+		}
+		if ( current_user_can( 'delete_term', $tag->term_id ) ) {
+			$actions['delete'] = sprintf(
+				'<a href="%s" class="delete-tag aria-button-if-js" aria-label="%s">%s</a>',
+				wp_nonce_url( "edit-tags.php?action=delete&amp;taxonomy=$taxonomy&amp;tag_ID=$tag->term_id", 'delete-tag_' . $tag->term_id ),
+				/* translators: %s: Taxonomy term name. */
+				esc_attr( sprintf( __( 'Delete &#8220;%s&#8221;' ), $tag->name ) ),
+				__( 'Delete' )
+			);
+		}
+		if ( is_taxonomy_viewable( $tax ) ) {
+			$actions['view'] = sprintf(
+				'<a href="%s" aria-label="%s">%s</a>',
+				get_term_link( $tag ),
+				/* translators: %s: Taxonomy term name. */
+				esc_attr( sprintf( __( 'View &#8220;%s&#8221; archive' ), $tag->name ) ),
+				__( 'View' )
+			);
 		}
-		if ( current_user_can( $tax->cap->delete_terms ) && $tag->term_id != $default_term )
-			$actions['delete'] = "<a class='delete-tag' href='" . wp_nonce_url( "edit-tags.php?action=delete&amp;taxonomy=$taxonomy&amp;tag_ID=$tag->term_id", 'delete-tag_' . $tag->term_id ) . "'>" . __( 'Delete' ) . "</a>";
-		if ( $tax->public )
-			$actions['view'] = '<a href="' . get_term_link( $tag ) . '">' . __( 'View' ) . '</a>';
 
 		/**
-		 * Filter the action links displayed for each term in the Tags list table.
+		 * Filters the action links displayed for each term in the Tags list table.
 		 *
 		 * @since 2.8.0
 		 * @deprecated 3.0.0 Use {$taxonomy}_row_actions instead.
 		 *
-		 * @param array  $actions An array of action links to be displayed. Default
-		 *                        'Edit', 'Quick Edit', 'Delete', and 'View'.
-		 * @param object $tag     Term object.
+		 * @param string[] $actions An array of action links to be displayed. Default
+		 *                          'Edit', 'Quick Edit', 'Delete', and 'View'.
+		 * @param WP_Term  $tag     Term object.
 		 */
 		$actions = apply_filters( 'tag_row_actions', $actions, $tag );
 
 		/**
-		 * Filter the action links displayed for each term in the terms list table.
+		 * Filters the action links displayed for each term in the terms list table.
 		 *
 		 * The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.
 		 *
 		 * @since 3.0.0
 		 *
-		 * @param array  $actions An array of action links to be displayed. Default
-		 *                        'Edit', 'Quick Edit', 'Delete', and 'View'.
-		 * @param object $tag     Term object.
+		 * @param string[] $actions An array of action links to be displayed. Default
+		 *                          'Edit', 'Quick Edit', 'Delete', and 'View'.
+		 * @param WP_Term  $tag     Term object.
 		 */
 		$actions = apply_filters( "{$taxonomy}_row_actions", $actions, $tag );
 
@@ -466,15 +527,19 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @return string
 	 */
 	public function column_description( $tag ) {
-		return $tag->description;
+		if ( $tag->description ) {
+			return $tag->description;
+		} else {
+			return '<span aria-hidden="true">&#8212;</span><span class="screen-reader-text">' . __( 'No description' ) . '</span>';
+		}
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @return string
 	 */
 	public function column_slug( $tag ) {
@@ -483,7 +548,7 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @return string
 	 */
 	public function column_posts( $tag ) {
@@ -492,43 +557,50 @@ class WP_Terms_List_Table extends WP_List_Table {
 		$tax = get_taxonomy( $this->screen->taxonomy );
 
 		$ptype_object = get_post_type_object( $this->screen->post_type );
-		if ( ! $ptype_object->show_ui )
+		if ( ! $ptype_object->show_ui ) {
 			return $count;
+		}
 
 		if ( $tax->query_var ) {
 			$args = array( $tax->query_var => $tag->slug );
 		} else {
-			$args = array( 'taxonomy' => $tax->name, 'term' => $tag->slug );
+			$args = array(
+				'taxonomy' => $tax->name,
+				'term'     => $tag->slug,
+			);
 		}
 
-		if ( 'post' != $this->screen->post_type )
+		if ( 'post' != $this->screen->post_type ) {
 			$args['post_type'] = $this->screen->post_type;
+		}
 
-		if ( 'attachment' === $this->screen->post_type )
-			return "<a href='" . esc_url ( add_query_arg( $args, 'upload.php' ) ) . "'>$count</a>";
+		if ( 'attachment' === $this->screen->post_type ) {
+			return "<a href='" . esc_url( add_query_arg( $args, 'upload.php' ) ) . "'>$count</a>";
+		}
 
-		return "<a href='" . esc_url ( add_query_arg( $args, 'edit.php' ) ) . "'>$count</a>";
+		return "<a href='" . esc_url( add_query_arg( $args, 'edit.php' ) ) . "'>$count</a>";
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @return string
 	 */
 	public function column_links( $tag ) {
 		$count = number_format_i18n( $tag->count );
-		if ( $count )
+		if ( $count ) {
 			$count = "<a href='link-manager.php?cat_id=$tag->term_id'>$count</a>";
+		}
 		return $count;
 	}
 
 	/**
-	 * @param object $tag
+	 * @param WP_Term $tag Term object.
 	 * @param string $column_name
 	 * @return string
 	 */
 	public function column_default( $tag, $column_name ) {
 		/**
-		 * Filter the displayed columns in the terms list table.
+		 * Filters the displayed columns in the terms list table.
 		 *
 		 * The dynamic portion of the hook name, `$this->screen->taxonomy`,
 		 * refers to the slug of the current taxonomy.
@@ -550,9 +622,10 @@ class WP_Terms_List_Table extends WP_List_Table {
 	public function inline_edit() {
 		$tax = get_taxonomy( $this->screen->taxonomy );
 
-		if ( ! current_user_can( $tax->cap->edit_terms ) )
+		if ( ! current_user_can( $tax->cap->edit_terms ) ) {
 			return;
-?>
+		}
+		?>
 
 	<form method="get"><table style="display: none"><tbody id="inlineedit">
 		<tr id="inline-edit" class="inline-edit-row" style="display: none"><td colspan="<?php echo $this->get_column_count(); ?>" class="colspanchange">
@@ -564,41 +637,50 @@ class WP_Terms_List_Table extends WP_List_Table {
 					<span class="title"><?php _ex( 'Name', 'term name' ); ?></span>
 					<span class="input-text-wrap"><input type="text" name="name" class="ptitle" value="" /></span>
 				</label>
-	<?php if ( !global_terms_enabled() ) { ?>
+		<?php if ( ! global_terms_enabled() ) { ?>
 				<label>
 					<span class="title"><?php _e( 'Slug' ); ?></span>
 					<span class="input-text-wrap"><input type="text" name="slug" class="ptitle" value="" /></span>
 				</label>
 	<?php } ?>
 			</div></fieldset>
-	<?php
+		<?php
 
-		$core_columns = array( 'cb' => true, 'description' => true, 'name' => true, 'slug' => true, 'posts' => true );
+		$core_columns = array(
+			'cb'          => true,
+			'description' => true,
+			'name'        => true,
+			'slug'        => true,
+			'posts'       => true,
+		);
 
 		list( $columns ) = $this->get_column_info();
 
 		foreach ( $columns as $column_name => $column_display_name ) {
-			if ( isset( $core_columns[$column_name] ) )
+			if ( isset( $core_columns[ $column_name ] ) ) {
 				continue;
+			}
 
 			/** This action is documented in wp-admin/includes/class-wp-posts-list-table.php */
 			do_action( 'quick_edit_custom_box', $column_name, 'edit-tags', $this->screen->taxonomy );
 		}
 
-	?>
+		?>
 
-		<p class="inline-edit-save submit">
-			<button type="button" class="cancel button-secondary alignleft"><?php _e( 'Cancel' ); ?></button>
-			<button type="button" class="save button-primary alignright"><?php echo $tax->labels->update_item; ?></button>
+		<div class="inline-edit-save submit">
+			<button type="button" class="cancel button alignleft"><?php _e( 'Cancel' ); ?></button>
+			<button type="button" class="save button button-primary alignright"><?php echo $tax->labels->update_item; ?></button>
 			<span class="spinner"></span>
-			<span class="error" style="display:none;"></span>
 			<?php wp_nonce_field( 'taxinlineeditnonce', '_inline_edit', false ); ?>
 			<input type="hidden" name="taxonomy" value="<?php echo esc_attr( $this->screen->taxonomy ); ?>" />
 			<input type="hidden" name="post_type" value="<?php echo esc_attr( $this->screen->post_type ); ?>" />
 			<br class="clear" />
-		</p>
+			<div class="notice notice-error notice-alt inline hidden">
+				<p class="error"></p>
+			</div>
+		</div>
 		</td></tr>
 		</tbody></table></form>
-	<?php
+		<?php
 	}
 }
