@@ -9,11 +9,13 @@
 
 require_once( dirname( __FILE__ ) . '/admin.php' );
 
-if ( !is_multisite() )
+if ( ! is_multisite() ) {
 	wp_die( __( 'Multisite support is not enabled.' ) );
+}
 
-if ( ! current_user_can('read') )
-	wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
+if ( ! current_user_can( 'read' ) ) {
+	wp_die( __( 'Sorry, you are not allowed to access this page.' ) );
+}
 
 $action = isset( $_POST['action'] ) ? $_POST['action'] : 'splash';
 
@@ -23,7 +25,7 @@ $updated = false;
 if ( 'updateblogsettings' == $action && isset( $_POST['primary_blog'] ) ) {
 	check_admin_referer( 'update-my-sites' );
 
-	$blog = get_blog_details( (int) $_POST['primary_blog'] );
+	$blog = get_site( (int) $_POST['primary_blog'] );
 	if ( $blog && isset( $blog->domain ) ) {
 		update_user_option( $current_user->ID, 'primary_blog', (int) $_POST['primary_blog'], true );
 		$updated = true;
@@ -32,21 +34,22 @@ if ( 'updateblogsettings' == $action && isset( $_POST['primary_blog'] ) ) {
 	}
 }
 
-$title = __( 'My Sites' );
+$title       = __( 'My Sites' );
 $parent_file = 'index.php';
 
-get_current_screen()->add_help_tab( array(
-	'id'      => 'overview',
-	'title'   => __('Overview'),
-	'content' =>
-		'<p>' . __('This screen shows an individual user all of their sites in this network, and also allows that user to set a primary site. They can use the links under each site to visit either the frontend or the dashboard for that site.') . '</p>' .
-		'<p>' . __('Up until WordPress version 3.0, what is now called a Multisite Network had to be installed separately as WordPress MU (multi-user).') . '</p>'
-) );
+get_current_screen()->add_help_tab(
+	array(
+		'id'      => 'overview',
+		'title'   => __( 'Overview' ),
+		'content' =>
+			'<p>' . __( 'This screen shows an individual user all of their sites in this network, and also allows that user to set a primary site. They can use the links under each site to visit either the front end or the dashboard for that site.' ) . '</p>',
+	)
+);
 
 get_current_screen()->set_help_sidebar(
-	'<p><strong>' . __('For more information:') . '</strong></p>' .
-	'<p>' . __('<a href="https://codex.wordpress.org/Dashboard_My_Sites_Screen" target="_blank">Documentation on My Sites</a>') . '</p>' .
-	'<p>' . __('<a href="https://wordpress.org/support/" target="_blank">Support Forums</a>') . '</p>'
+	'<p><strong>' . __( 'For more information:' ) . '</strong></p>' .
+	'<p>' . __( '<a href="https://codex.wordpress.org/Dashboard_My_Sites_Screen">Documentation on My Sites</a>' ) . '</p>' .
+	'<p>' . __( '<a href="https://wordpress.org/support/">Support</a>' ) . '</p>'
 );
 
 require_once( ABSPATH . 'wp-admin/admin-header.php' );
@@ -56,23 +59,28 @@ if ( $updated ) { ?>
 <?php } ?>
 
 <div class="wrap">
-<h1><?php
+<h1 class="wp-heading-inline">
+<?php
 echo esc_html( $title );
+?>
+</h1>
 
+<?php
 if ( in_array( get_site_option( 'registration' ), array( 'all', 'blog' ) ) ) {
 	/** This filter is documented in wp-login.php */
 	$sign_up_url = apply_filters( 'wp_signup_location', network_site_url( 'wp-signup.php' ) );
 	printf( ' <a href="%s" class="page-title-action">%s</a>', esc_url( $sign_up_url ), esc_html_x( 'Add New', 'site' ) );
 }
-?></h1>
 
-<?php
 if ( empty( $blogs ) ) :
 	echo '<p>';
 	_e( 'You must be a member of at least one site to use this page.' );
 	echo '</p>';
 else :
-?>
+	?>
+
+<hr class="wp-header-end">
+
 <form id="myblogs" method="post">
 	<?php
 	choose_primary_blog();
@@ -93,7 +101,7 @@ else :
 	 * string to this filter will enable the section, and allow new settings
 	 * to be added, either globally or for specific sites.
 	 *
-	 * @since MU
+	 * @since MU (3.0.0)
 	 *
 	 * @param string $settings_html The settings HTML markup. Default empty.
 	 * @param object $context       Context of the setting (global or site-specific). Default 'global'.
@@ -106,25 +114,41 @@ else :
 	reset( $blogs );
 
 	foreach ( $blogs as $user_blog ) {
-		echo "<li>";
+		switch_to_blog( $user_blog->userblog_id );
+
+		echo '<li>';
 		echo "<h3>{$user_blog->blogname}</h3>";
+
+		$actions = "<a href='" . esc_url( home_url() ) . "'>" . __( 'Visit' ) . '</a>';
+
+		if ( current_user_can( 'read' ) ) {
+			$actions .= " | <a href='" . esc_url( admin_url() ) . "'>" . __( 'Dashboard' ) . '</a>';
+		}
+
 		/**
-		 * Filter the row links displayed for each site on the My Sites screen.
+		 * Filters the row links displayed for each site on the My Sites screen.
 		 *
-		 * @since MU
+		 * @since MU (3.0.0)
 		 *
-		 * @param string $string    The HTML site link markup.
+		 * @param string $actions   The HTML site link markup.
 		 * @param object $user_blog An object containing the site data.
 		 */
-		echo "<p class='my-sites-actions'>" . apply_filters( 'myblogs_blog_actions', "<a href='" . esc_url( get_home_url( $user_blog->userblog_id ) ). "'>" . __( 'Visit' ) . "</a> | <a href='" . esc_url( get_admin_url( $user_blog->userblog_id ) ) . "'>" . __( 'Dashboard' ) . "</a>", $user_blog ) . "</p>";
+		$actions = apply_filters( 'myblogs_blog_actions', $actions, $user_blog );
+		echo "<p class='my-sites-actions'>" . $actions . '</p>';
+
 		/** This filter is documented in wp-admin/my-sites.php */
 		echo apply_filters( 'myblogs_options', '', $user_blog );
-		echo "</li>";
-	}?>
+		echo '</li>';
+
+		restore_current_blog();
+	}
+	?>
 	</ul>
 	<?php
 	if ( count( $blogs ) > 1 || has_action( 'myblogs_allblogs_options' ) || has_filter( 'myblogs_options' ) ) {
-		?><input type="hidden" name="action" value="updateblogsettings" /><?php
+		?>
+		<input type="hidden" name="action" value="updateblogsettings" />
+		<?php
 		wp_nonce_field( 'update-my-sites' );
 		submit_button();
 	}
