@@ -4,7 +4,7 @@
  *
  * Used in Search Results and for Recent Posts in Front Page panels.
  *
- * @link https://codex.wordpress.org/Template_Hierarchy
+ * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
  *
  * @package WordPress
  * @subpackage Twenty_Seventeen
@@ -30,17 +30,19 @@
 			</div><!-- .entry-meta -->
 		<?php endif; ?>
 
-		<?php if ( is_front_page() && ! is_home() ) {
+		<?php
+		if ( is_front_page() && ! is_home() ) {
 
 			// The excerpt is being displayed within a front page section, so it's a lower hierarchy than h2.
 			the_title( sprintf( '<h3 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
 		} else {
 			the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
-		} ?>
+		}
+		?>
 	</header><!-- .entry-header -->
 
 	<div class="entry-summary">
 		<?php the_excerpt(); ?>
 	</div><!-- .entry-summary -->
 
-</article><!-- #post-## -->
+</article><!-- #post-<?php the_ID(); ?> -->
