@@ -23,17 +23,16 @@ class WP_Admin_Bar {
 	 */
 	public function __get( $name ) {
 		switch ( $name ) {
-			case 'proto' :
+			case 'proto':
 				return is_ssl() ? 'https://' : 'http://';
 
-			case 'menu' :
-				_deprecated_argument( 'WP_Admin_Bar', '3.3', 'Modify admin bar nodes with WP_Admin_Bar::get_node(), WP_Admin_Bar::add_node(), and WP_Admin_Bar::remove_node(), not the <code>menu</code> property.' );
+			case 'menu':
+				_deprecated_argument( 'WP_Admin_Bar', '3.3.0', 'Modify admin bar nodes with WP_Admin_Bar::get_node(), WP_Admin_Bar::add_node(), and WP_Admin_Bar::remove_node(), not the <code>menu</code> property.' );
 				return array(); // Sorry, folks.
 		}
 	}
 
 	/**
-	 * @access public
 	 */
 	public function initialize() {
 		$this->user = new stdClass;
@@ -42,12 +41,12 @@ class WP_Admin_Bar {
 			/* Populate settings we need for the menu based on the current user. */
 			$this->user->blogs = get_blogs_of_user( get_current_user_id() );
 			if ( is_multisite() ) {
-				$this->user->active_blog = get_active_blog_for_user( get_current_user_id() );
-				$this->user->domain = empty( $this->user->active_blog ) ? user_admin_url() : trailingslashit( get_home_url( $this->user->active_blog->blog_id ) );
+				$this->user->active_blog    = get_active_blog_for_user( get_current_user_id() );
+				$this->user->domain         = empty( $this->user->active_blog ) ? user_admin_url() : trailingslashit( get_home_url( $this->user->active_blog->blog_id ) );
 				$this->user->account_domain = $this->user->domain;
 			} else {
-				$this->user->active_blog = $this->user->blogs[get_current_blog_id()];
-				$this->user->domain = trailingslashit( home_url() );
+				$this->user->active_blog    = $this->user->blogs[ get_current_blog_id() ];
+				$this->user->domain         = trailingslashit( home_url() );
 				$this->user->account_domain = $this->user->domain;
 			}
 		}
@@ -61,14 +60,15 @@ class WP_Admin_Bar {
 			 * To remove the default padding styles from WordPress for the Toolbar, use the following code:
 			 * add_theme_support( 'admin-bar', array( 'callback' => '__return_false' ) );
 			 */
-			$admin_bar_args = get_theme_support( 'admin-bar' );
+			$admin_bar_args  = get_theme_support( 'admin-bar' );
 			$header_callback = $admin_bar_args[0]['callback'];
 		}
 
-		if ( empty($header_callback) )
+		if ( empty( $header_callback ) ) {
 			$header_callback = '_admin_bar_bump_cb';
+		}
 
-		add_action('wp_head', $header_callback);
+		add_action( 'wp_head', $header_callback );
 
 		wp_enqueue_script( 'admin-bar' );
 		wp_enqueue_style( 'admin-bar' );
@@ -96,7 +96,10 @@ class WP_Admin_Bar {
 	}
 
 	/**
-	 * Add a node to the menu.
+	 * Adds a node to the menu.
+	 *
+	 * @since 3.1.0
+	 * @since 4.5.0 Added the ability to pass 'lang' and 'dir' meta data.
 	 *
 	 * @param array $args {
 	 *     Arguments for adding a node.
@@ -106,24 +109,27 @@ class WP_Admin_Bar {
 	 *     @type string $parent Optional. ID of the parent node.
 	 *     @type string $href   Optional. Link for the item.
 	 *     @type bool   $group  Optional. Whether or not the node is a group. Default false.
-	 *     @type array  $meta   Meta data including the following keys: 'html', 'class', 'rel',
+	 *     @type array  $meta   Meta data including the following keys: 'html', 'class', 'rel', 'lang', 'dir',
 	 *                          'onclick', 'target', 'title', 'tabindex'. Default empty.
 	 * }
 	 */
 	public function add_node( $args ) {
 		// Shim for old method signature: add_node( $parent_id, $menu_obj, $args )
-		if ( func_num_args() >= 3 && is_string( func_get_arg(0) ) )
-			$args = array_merge( array( 'parent' => func_get_arg(0) ), func_get_arg(2) );
+		if ( func_num_args() >= 3 && is_string( $args ) ) {
+			$args = array_merge( array( 'parent' => $args ), func_get_arg( 2 ) );
+		}
 
-		if ( is_object( $args ) )
+		if ( is_object( $args ) ) {
 			$args = get_object_vars( $args );
+		}
 
 		// Ensure we have a valid title.
 		if ( empty( $args['id'] ) ) {
-			if ( empty( $args['title'] ) )
+			if ( empty( $args['title'] ) ) {
 				return;
+			}
 
-			_doing_it_wrong( __METHOD__, __( 'The menu ID should not be empty.' ), '3.3' );
+			_doing_it_wrong( __METHOD__, __( 'The menu ID should not be empty.' ), '3.3.0' );
 			// Deprecated: Generate an ID from the title.
 			$args['id'] = esc_attr( sanitize_title( trim( $args['title'] ) ) );
 		}
@@ -138,18 +144,21 @@ class WP_Admin_Bar {
 		);
 
 		// If the node already exists, keep any data that isn't provided.
-		if ( $maybe_defaults = $this->get_node( $args['id'] ) )
+		$maybe_defaults = $this->get_node( $args['id'] );
+		if ( $maybe_defaults ) {
 			$defaults = get_object_vars( $maybe_defaults );
+		}
 
 		// Do the same for 'meta' items.
-		if ( ! empty( $defaults['meta'] ) && ! empty( $args['meta'] ) )
+		if ( ! empty( $defaults['meta'] ) && ! empty( $args['meta'] ) ) {
 			$args['meta'] = wp_parse_args( $args['meta'], $defaults['meta'] );
+		}
 
 		$args = wp_parse_args( $args, $defaults );
 
 		$back_compat_parents = array(
 			'my-account-with-avatar' => array( 'my-account', '3.3' ),
-			'my-blogs'               => array( 'my-sites',   '3.3' ),
+			'my-blogs'               => array( 'my-sites', '3.3' ),
 		);
 
 		if ( isset( $back_compat_parents[ $args['parent'] ] ) ) {
@@ -172,11 +181,13 @@ class WP_Admin_Bar {
 	 * Gets a node.
 	 *
 	 * @param string $id
-	 * @return object Node.
+	 * @return object|void Node.
 	 */
 	final public function get_node( $id ) {
-		if ( $node = $this->_get_node( $id ) )
+		$node = $this->_get_node( $id );
+		if ( $node ) {
 			return clone $node;
+		}
 	}
 
 	/**
@@ -184,22 +195,27 @@ class WP_Admin_Bar {
 	 * @return object|void
 	 */
 	final protected function _get_node( $id ) {
-		if ( $this->bound )
+		if ( $this->bound ) {
 			return;
+		}
 
-		if ( empty( $id ) )
+		if ( empty( $id ) ) {
 			$id = 'root';
+		}
 
-		if ( isset( $this->nodes[ $id ] ) )
+		if ( isset( $this->nodes[ $id ] ) ) {
 			return $this->nodes[ $id ];
+		}
 	}
 
 	/**
 	 * @return array|void
 	 */
 	final public function get_nodes() {
-		if ( ! $nodes = $this->_get_nodes() )
+		$nodes = $this->_get_nodes();
+		if ( ! $nodes ) {
 			return;
+		}
 
 		foreach ( $nodes as &$node ) {
 			$node = clone $node;
@@ -211,8 +227,9 @@ class WP_Admin_Bar {
 	 * @return array|void
 	 */
 	final protected function _get_nodes() {
-		if ( $this->bound )
+		if ( $this->bound ) {
 			return;
+		}
 
 		return $this->nodes;
 	}
@@ -254,46 +271,52 @@ class WP_Admin_Bar {
 	}
 
 	/**
-	 * @access public
 	 */
 	public function render() {
 		$root = $this->_bind();
-		if ( $root )
+		if ( $root ) {
 			$this->_render( $root );
+		}
 	}
 
 	/**
 	 * @return object|void
 	 */
 	final protected function _bind() {
-		if ( $this->bound )
+		if ( $this->bound ) {
 			return;
+		}
 
 		// Add the root node.
 		// Clear it first, just in case. Don't mess with The Root.
 		$this->remove_node( 'root' );
-		$this->add_node( array(
-			'id'    => 'root',
-			'group' => false,
-		) );
+		$this->add_node(
+			array(
+				'id'    => 'root',
+				'group' => false,
+			)
+		);
 
 		// Normalize nodes: define internal 'children' and 'type' properties.
 		foreach ( $this->_get_nodes() as $node ) {
 			$node->children = array();
-			$node->type = ( $node->group ) ? 'group' : 'item';
+			$node->type     = ( $node->group ) ? 'group' : 'item';
 			unset( $node->group );
 
 			// The Root wants your orphans. No lonely items allowed.
-			if ( ! $node->parent )
+			if ( ! $node->parent ) {
 				$node->parent = 'root';
+			}
 		}
 
 		foreach ( $this->_get_nodes() as $node ) {
-			if ( 'root' == $node->id )
+			if ( 'root' == $node->id ) {
 				continue;
+			}
 
 			// Fetch the parent node. If it isn't registered, ignore the node.
-			if ( ! $parent = $this->_get_node( $node->parent ) ) {
+			$parent = $this->_get_node( $node->parent );
+			if ( ! $parent ) {
 				continue;
 			}
 
@@ -301,10 +324,11 @@ class WP_Admin_Bar {
 			$group_class = ( $node->parent == 'root' ) ? 'ab-top-menu' : 'ab-submenu';
 
 			if ( $node->type == 'group' ) {
-				if ( empty( $node->meta['class'] ) )
+				if ( empty( $node->meta['class'] ) ) {
 					$node->meta['class'] = $group_class;
-				else
+				} else {
 					$node->meta['class'] .= ' ' . $group_class;
+				}
 			}
 
 			// Items in items aren't allowed. Wrap nested items in 'default' groups.
@@ -317,24 +341,26 @@ class WP_Admin_Bar {
 				if ( ! $default ) {
 					// Use _set_node because add_node can be overloaded.
 					// Make sure to specify default settings for all properties.
-					$this->_set_node( array(
-						'id'        => $default_id,
-						'parent'    => $parent->id,
-						'type'      => 'group',
-						'children'  => array(),
-						'meta'      => array(
-							'class'     => $group_class,
-						),
-						'title'     => false,
-						'href'      => false,
-					) );
-					$default = $this->_get_node( $default_id );
+					$this->_set_node(
+						array(
+							'id'       => $default_id,
+							'parent'   => $parent->id,
+							'type'     => 'group',
+							'children' => array(),
+							'meta'     => array(
+								'class' => $group_class,
+							),
+							'title'    => false,
+							'href'     => false,
+						)
+					);
+					$default            = $this->_get_node( $default_id );
 					$parent->children[] = $default;
 				}
 				$parent = $default;
 
-			// Groups in groups aren't allowed. Add a special 'container' node.
-			// The container will invisibly wrap both groups.
+				// Groups in groups aren't allowed. Add a special 'container' node.
+				// The container will invisibly wrap both groups.
 			} elseif ( $parent->type == 'group' && $node->type == 'group' ) {
 				$container_id = $parent->id . '-container';
 				$container    = $this->_get_node( $container_id );
@@ -343,15 +369,17 @@ class WP_Admin_Bar {
 				if ( ! $container ) {
 					// Use _set_node because add_node can be overloaded.
 					// Make sure to specify default settings for all properties.
-					$this->_set_node( array(
-						'id'       => $container_id,
-						'type'     => 'container',
-						'children' => array( $parent ),
-						'parent'   => false,
-						'title'    => false,
-						'href'     => false,
-						'meta'     => array(),
-					) );
+					$this->_set_node(
+						array(
+							'id'       => $container_id,
+							'type'     => 'container',
+							'children' => array( $parent ),
+							'parent'   => false,
+							'title'    => false,
+							'href'     => false,
+							'meta'     => array(),
+						)
+					);
 
 					$container = $this->_get_node( $container_id );
 
@@ -362,10 +390,11 @@ class WP_Admin_Bar {
 						$container->parent = $grandparent->id;
 
 						$index = array_search( $parent, $grandparent->children, true );
-						if ( $index === false )
+						if ( $index === false ) {
 							$grandparent->children[] = $container;
-						else
+						} else {
 							array_splice( $grandparent->children, $index, 1, array( $container ) );
+						}
 					}
 
 					$parent->parent = $container->id;
@@ -381,13 +410,12 @@ class WP_Admin_Bar {
 			$parent->children[] = $node;
 		}
 
-		$root = $this->_get_node( 'root' );
+		$root        = $this->_get_node( 'root' );
 		$this->bound = true;
 		return $root;
 	}
 
 	/**
-	 *
 	 * @global bool $is_IE
 	 * @param object $root
 	 */
@@ -398,12 +426,13 @@ class WP_Admin_Bar {
 		// We have to do this here since admin bar shows on the front end.
 		$class = 'nojq nojs';
 		if ( $is_IE ) {
-			if ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 7' ) )
+			if ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 7' ) ) {
 				$class .= ' ie7';
-			elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 8' ) )
+			} elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 8' ) ) {
 				$class .= ' ie8';
-			elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 9' ) )
+			} elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 9' ) ) {
 				$class .= ' ie9';
+			}
 		} elseif ( wp_is_mobile() ) {
 			$class .= ' mobile';
 		}
@@ -413,13 +442,15 @@ class WP_Admin_Bar {
 			<?php if ( ! is_admin() ) { ?>
 				<a class="screen-reader-shortcut" href="#wp-toolbar" tabindex="1"><?php _e( 'Skip to toolbar' ); ?></a>
 			<?php } ?>
-			<div class="quicklinks" id="wp-toolbar" role="navigation" aria-label="<?php esc_attr_e( 'Toolbar' ); ?>" tabindex="0">
-				<?php foreach ( $root->children as $group ) {
+			<div class="quicklinks" id="wp-toolbar" role="navigation" aria-label="<?php esc_attr_e( 'Toolbar' ); ?>">
+				<?php
+				foreach ( $root->children as $group ) {
 					$this->_render_group( $group );
-				} ?>
+				}
+				?>
 			</div>
 			<?php if ( is_user_logged_in() ) : ?>
-			<a class="screen-reader-shortcut" href="<?php echo esc_url( wp_logout_url() ); ?>"><?php _e('Log Out'); ?></a>
+			<a class="screen-reader-shortcut" href="<?php echo esc_url( wp_logout_url() ); ?>"><?php _e( 'Log Out' ); ?></a>
 			<?php endif; ?>
 		</div>
 
@@ -430,14 +461,15 @@ class WP_Admin_Bar {
 	 * @param object $node
 	 */
 	final protected function _render_container( $node ) {
-		if ( $node->type != 'container' || empty( $node->children ) )
+		if ( $node->type != 'container' || empty( $node->children ) ) {
 			return;
+		}
 
-		?><div id="<?php echo esc_attr( 'wp-admin-bar-' . $node->id ); ?>" class="ab-group-container"><?php
-			foreach ( $node->children as $group ) {
-				$this->_render_group( $group );
-			}
-		?></div><?php
+		echo '<div id="' . esc_attr( 'wp-admin-bar-' . $node->id ) . '" class="ab-group-container">';
+		foreach ( $node->children as $group ) {
+			$this->_render_group( $group );
+		}
+		echo '</div>';
 	}
 
 	/**
@@ -448,113 +480,127 @@ class WP_Admin_Bar {
 			$this->_render_container( $node );
 			return;
 		}
-		if ( $node->type != 'group' || empty( $node->children ) )
+		if ( $node->type != 'group' || empty( $node->children ) ) {
 			return;
+		}
 
-		if ( ! empty( $node->meta['class'] ) )
+		if ( ! empty( $node->meta['class'] ) ) {
 			$class = ' class="' . esc_attr( trim( $node->meta['class'] ) ) . '"';
-		else
+		} else {
 			$class = '';
+		}
 
-		?><ul id="<?php echo esc_attr( 'wp-admin-bar-' . $node->id ); ?>"<?php echo $class; ?>><?php
-			foreach ( $node->children as $item ) {
-				$this->_render_item( $item );
-			}
-		?></ul><?php
+		echo "<ul id='" . esc_attr( 'wp-admin-bar-' . $node->id ) . "'$class>";
+		foreach ( $node->children as $item ) {
+			$this->_render_item( $item );
+		}
+		echo '</ul>';
 	}
 
 	/**
 	 * @param object $node
 	 */
 	final protected function _render_item( $node ) {
-		if ( $node->type != 'item' )
+		if ( $node->type != 'item' ) {
 			return;
+		}
 
-		$is_parent = ! empty( $node->children );
-		$has_link  = ! empty( $node->href );
+		$is_parent             = ! empty( $node->children );
+		$has_link              = ! empty( $node->href );
+		$is_root_top_item      = 'root-default' === $node->parent;
+		$is_top_secondary_item = 'top-secondary' === $node->parent;
 
-		$tabindex = isset( $node->meta['tabindex'] ) ? (int) $node->meta['tabindex'] : '';
-		$aria_attributes = $tabindex ? 'tabindex="' . $tabindex . '"' : '';
+		// Allow only numeric values, then casted to integers, and allow a tabindex value of `0` for a11y.
+		$tabindex        = ( isset( $node->meta['tabindex'] ) && is_numeric( $node->meta['tabindex'] ) ) ? (int) $node->meta['tabindex'] : '';
+		$aria_attributes = ( '' !== $tabindex ) ? ' tabindex="' . $tabindex . '"' : '';
 
 		$menuclass = '';
+		$arrow     = '';
 
 		if ( $is_parent ) {
-			$menuclass = 'menupop ';
+			$menuclass        = 'menupop ';
 			$aria_attributes .= ' aria-haspopup="true"';
 		}
 
-		if ( ! empty( $node->meta['class'] ) )
+		if ( ! empty( $node->meta['class'] ) ) {
 			$menuclass .= $node->meta['class'];
+		}
 
-		if ( $menuclass )
+		// Print the arrow icon for the menu children with children.
+		if ( ! $is_root_top_item && ! $is_top_secondary_item && $is_parent ) {
+			$arrow = '<span class="wp-admin-bar-arrow" aria-hidden="true"></span>';
+		}
+
+		if ( $menuclass ) {
 			$menuclass = ' class="' . esc_attr( trim( $menuclass ) ) . '"';
+		}
 
-		?>
+		echo "<li id='" . esc_attr( 'wp-admin-bar-' . $node->id ) . "'$menuclass>";
 
-		<li id="<?php echo esc_attr( 'wp-admin-bar-' . $node->id ); ?>"<?php echo $menuclass; ?>><?php
-			if ( $has_link ):
-				?><a class="ab-item" <?php echo $aria_attributes; ?> href="<?php echo esc_url( $node->href ) ?>"<?php
-					if ( ! empty( $node->meta['onclick'] ) ) :
-						?> onclick="<?php echo esc_js( $node->meta['onclick'] ); ?>"<?php
-					endif;
-				if ( ! empty( $node->meta['target'] ) ) :
-					?> target="<?php echo esc_attr( $node->meta['target'] ); ?>"<?php
-				endif;
-				if ( ! empty( $node->meta['title'] ) ) :
-					?> title="<?php echo esc_attr( $node->meta['title'] ); ?>"<?php
-				endif;
-				if ( ! empty( $node->meta['rel'] ) ) :
-					?> rel="<?php echo esc_attr( $node->meta['rel'] ); ?>"<?php
-				endif;
-				?>><?php
-			else:
-				?><div class="ab-item ab-empty-item" <?php echo $aria_attributes;
-				if ( ! empty( $node->meta['title'] ) ) :
-					?> title="<?php echo esc_attr( $node->meta['title'] ); ?>"<?php
-				endif;
-				?>><?php
-			endif;
+		if ( $has_link ) {
+			$attributes = array( 'onclick', 'target', 'title', 'rel', 'lang', 'dir' );
+			echo "<a class='ab-item'$aria_attributes href='" . esc_url( $node->href ) . "'";
+			if ( ! empty( $node->meta['onclick'] ) ) {
+				echo ' onclick="' . esc_js( $node->meta['onclick'] ) . '"';
+			}
+		} else {
+			$attributes = array( 'onclick', 'target', 'title', 'rel', 'lang', 'dir' );
+			echo '<div class="ab-item ab-empty-item"' . $aria_attributes;
+		}
 
-			echo $node->title;
+		foreach ( $attributes as $attribute ) {
+			if ( ! empty( $node->meta[ $attribute ] ) ) {
+				echo " $attribute='" . esc_attr( $node->meta[ $attribute ] ) . "'";
+			}
+		}
 
-			if ( $has_link ) :
-				?></a><?php
-			else:
-				?></div><?php
-			endif;
+		echo ">{$arrow}{$node->title}";
 
-			if ( $is_parent ) :
-				?><div class="ab-sub-wrapper"><?php
-					foreach ( $node->children as $group ) {
-						$this->_render_group( $group );
-					}
-				?></div><?php
-			endif;
+		if ( $has_link ) {
+			echo '</a>';
+		} else {
+			echo '</div>';
+		}
 
-			if ( ! empty( $node->meta['html'] ) )
-				echo $node->meta['html'];
+		if ( $is_parent ) {
+			echo '<div class="ab-sub-wrapper">';
+			foreach ( $node->children as $group ) {
+				$this->_render_group( $group );
+			}
+			echo '</div>';
+		}
 
-			?>
-		</li><?php
+		if ( ! empty( $node->meta['html'] ) ) {
+			echo $node->meta['html'];
+		}
+
+		echo '</li>';
 	}
 
 	/**
+	 * Renders toolbar items recursively.
+	 *
+	 * @since 3.1.0
+	 * @deprecated 3.3.0 Use WP_Admin_Bar::_render_item() or WP_Admin_bar::render() instead.
+	 * @see WP_Admin_Bar::_render_item()
+	 * @see WP_Admin_Bar::render()
+	 *
 	 * @param string $id    Unused.
 	 * @param object $node
 	 */
 	public function recursive_render( $id, $node ) {
-		_deprecated_function( __METHOD__, '3.3', 'WP_Admin_bar::render(), WP_Admin_Bar::_render_item()' );
+		_deprecated_function( __METHOD__, '3.3.0', 'WP_Admin_bar::render(), WP_Admin_Bar::_render_item()' );
 		$this->_render_item( $node );
 	}
 
 	/**
-	 * @access public
 	 */
 	public function add_menus() {
 		// User related, aligned right.
 		add_action( 'admin_bar_menu', 'wp_admin_bar_my_account_menu', 0 );
 		add_action( 'admin_bar_menu', 'wp_admin_bar_search_menu', 4 );
 		add_action( 'admin_bar_menu', 'wp_admin_bar_my_account_item', 7 );
+		add_action( 'admin_bar_menu', 'wp_admin_bar_recovery_mode_menu', 8 );
 
 		// Site related.
 		add_action( 'admin_bar_menu', 'wp_admin_bar_sidebar_toggle', 0 );
